Uses of Class
com.github.copilot.CopilotRequestContext
Packages that use CopilotRequestContext
-
Uses of CopilotRequestContext in com.github.copilot
Methods in com.github.copilot that return CopilotRequestContextModifier and TypeMethodDescriptionCopilotRequestContext.withHeaders(Map<String, List<String>> headers) Returns a copy of this context with different request headers.Returns a copy of this context with a different request URL.Constructors in com.github.copilot with parameters of type CopilotRequestContextModifierConstructorDescriptionCreates a forwarding handler targeting the request URL and headers fromcontext.