Record Class McpResourcesListChangedEvent.McpResourcesListChangedEventData

java.lang.Object
java.lang.Record
com.github.copilot.generated.McpResourcesListChangedEvent.McpResourcesListChangedEventData
Enclosing class:
McpResourcesListChangedEvent

public static record McpResourcesListChangedEvent.McpResourcesListChangedEventData(String serverName) extends Record
Since:
1.0.0
  • Constructor Summary

    Constructors
    Constructor
    Description
    Creates an instance of a McpResourcesListChangedEventData record class.
  • Method Summary

    Modifier and Type
    Method
    Description
    final boolean
    Indicates whether some other object is "equal to" this one.
    final int
    Returns a hash code value for this object.
    Returns the value of the serverName record component.
    final String
    Returns a string representation of this record class.

    Methods inherited from class Object

    getClass, notify, notifyAll, wait, wait, wait
  • Constructor Details

    • McpResourcesListChangedEventData

      public McpResourcesListChangedEventData(String serverName)
      Creates an instance of a McpResourcesListChangedEventData record class.
      Parameters:
      serverName - the value for the serverName record component
  • Method Details

    • toString

      public final String toString()
      Returns a string representation of this record class. The representation contains the name of the class, followed by the name and value of each of the record components.
      Specified by:
      toString in class Record
      Returns:
      a string representation of this object
    • hashCode

      public final int hashCode()
      Returns a hash code value for this object. The value is derived from the hash code of each of the record components.
      Specified by:
      hashCode in class Record
      Returns:
      a hash code value for this object
    • equals

      public final boolean equals(Object o)
      Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared with Objects::equals(Object,Object).
      Specified by:
      equals in class Record
      Parameters:
      o - the object with which to compare
      Returns:
      true if this object is the same as the o argument; false otherwise.
    • serverName

      public String serverName()
      Returns the value of the serverName record component.
      Returns:
      the value of the serverName record component