Record Class ResponseLimitsConfig
java.lang.Object
java.lang.Record
com.github.copilot.generated.ResponseLimitsConfig
@Generated("copilot-sdk-codegen")
public record ResponseLimitsConfig(Double maxAiCredits)
extends Record
Optional response limits.
- Since:
- 1.0.0
-
Constructor Summary
ConstructorsConstructorDescriptionResponseLimitsConfig(Double maxAiCredits) Creates an instance of aResponseLimitsConfigrecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of themaxAiCreditsrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
ResponseLimitsConfig
Creates an instance of aResponseLimitsConfigrecord class.- Parameters:
maxAiCredits- the value for themaxAiCreditsrecord component
-
-
Method Details
-
toString
-
hashCode
-
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
maxAiCredits
Returns the value of themaxAiCreditsrecord component.- Returns:
- the value of the
maxAiCreditsrecord component
-