Record Class SessionResponseLimitsChangedEvent.SessionResponseLimitsChangedEventData
java.lang.Object
java.lang.Record
com.github.copilot.generated.SessionResponseLimitsChangedEvent.SessionResponseLimitsChangedEventData
- Enclosing class:
SessionResponseLimitsChangedEvent
public static record SessionResponseLimitsChangedEvent.SessionResponseLimitsChangedEventData(ResponseLimitsConfig responseLimits)
extends Record
Data payload for
SessionResponseLimitsChangedEvent.- Since:
- 1.0.0
-
Constructor Summary
ConstructorsConstructorDescriptionSessionResponseLimitsChangedEventData(ResponseLimitsConfig responseLimits) Creates an instance of aSessionResponseLimitsChangedEventDatarecord class. -
Method Summary
Modifier and TypeMethodDescriptionfinal booleanIndicates whether some other object is "equal to" this one.final inthashCode()Returns a hash code value for this object.Returns the value of theresponseLimitsrecord component.final StringtoString()Returns a string representation of this record class.
-
Constructor Details
-
SessionResponseLimitsChangedEventData
Creates an instance of aSessionResponseLimitsChangedEventDatarecord class.- Parameters:
responseLimits- the value for theresponseLimitsrecord component
-
-
Method Details
-
toString
-
hashCode
-
equals
Indicates whether some other object is "equal to" this one. The objects are equal if the other object is of the same class and if all the record components are equal. All components in this record class are compared withObjects::equals(Object,Object). -
responseLimits
Returns the value of theresponseLimitsrecord component.- Returns:
- the value of the
responseLimitsrecord component
-